# Changelog

## 3.19.0 (2024-07-01)

Full Changelog: [v3.18.0...v3.19.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.18.0...v3.19.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#119](https://github.com/RetellAI/retell-python-sdk/issues/119)) ([18c6154](https://github.com/RetellAI/retell-python-sdk/commit/18c61544264369c882bf3c2505bcaa6378148c3e))
* **api:** OpenAPI spec update via Stainless API ([#121](https://github.com/RetellAI/retell-python-sdk/issues/121)) ([ae5868e](https://github.com/RetellAI/retell-python-sdk/commit/ae5868edb0fd3af092027708594e748f235f5189))
* **api:** OpenAPI spec update via Stainless API ([#122](https://github.com/RetellAI/retell-python-sdk/issues/122)) ([22c79c7](https://github.com/RetellAI/retell-python-sdk/commit/22c79c72ab2038d614a75acab6290184efedb978))
* **api:** OpenAPI spec update via Stainless API ([#123](https://github.com/RetellAI/retell-python-sdk/issues/123)) ([b4f187c](https://github.com/RetellAI/retell-python-sdk/commit/b4f187cf5e324b64161052b20a9fdb2e1ca59b48))
* **api:** OpenAPI spec update via Stainless API ([#124](https://github.com/RetellAI/retell-python-sdk/issues/124)) ([577c939](https://github.com/RetellAI/retell-python-sdk/commit/577c939bf49272b170938bf5686aaeafcff7ba5f))
* **api:** OpenAPI spec update via Stainless API ([#125](https://github.com/RetellAI/retell-python-sdk/issues/125)) ([fe98d7e](https://github.com/RetellAI/retell-python-sdk/commit/fe98d7e86c8559266a9add5ea96b64cb12db2ce2))
* **api:** OpenAPI spec update via Stainless API ([#126](https://github.com/RetellAI/retell-python-sdk/issues/126)) ([ccef7fb](https://github.com/RetellAI/retell-python-sdk/commit/ccef7fb7e646ffa0f7bb1e9e53478a068837e5f8))
* **api:** OpenAPI spec update via Stainless API ([#127](https://github.com/RetellAI/retell-python-sdk/issues/127)) ([c4c65b1](https://github.com/RetellAI/retell-python-sdk/commit/c4c65b1f3dc988a2b7f090f3630bb5f114e21c03))
* **api:** OpenAPI spec update via Stainless API ([#128](https://github.com/RetellAI/retell-python-sdk/issues/128)) ([44ba1ed](https://github.com/RetellAI/retell-python-sdk/commit/44ba1ed9a48766bfb511fa3c9e9d272b333df84f))
* **api:** OpenAPI spec update via Stainless API ([#129](https://github.com/RetellAI/retell-python-sdk/issues/129)) ([971b2c7](https://github.com/RetellAI/retell-python-sdk/commit/971b2c7de442dd264b2fcca2bf1ec9d290743351))

## 3.18.0 (2024-06-06)

Full Changelog: [v3.17.0...v3.18.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.17.0...v3.18.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#108](https://github.com/RetellAI/retell-python-sdk/issues/108)) ([73424e3](https://github.com/RetellAI/retell-python-sdk/commit/73424e38af207759d9fe06ba5b8331084fe0383e))
* **api:** OpenAPI spec update via Stainless API ([#110](https://github.com/RetellAI/retell-python-sdk/issues/110)) ([a905225](https://github.com/RetellAI/retell-python-sdk/commit/a9052251dee723affde699de25005ef7938cd5e6))
* **api:** OpenAPI spec update via Stainless API ([#111](https://github.com/RetellAI/retell-python-sdk/issues/111)) ([4243ead](https://github.com/RetellAI/retell-python-sdk/commit/4243ead63925b997a780892b961a5e19b64d80bb))
* **api:** OpenAPI spec update via Stainless API ([#112](https://github.com/RetellAI/retell-python-sdk/issues/112)) ([3ad4a2d](https://github.com/RetellAI/retell-python-sdk/commit/3ad4a2dd30b0d1582c04a2231e7b61fcf01128c3))
* **api:** OpenAPI spec update via Stainless API ([#113](https://github.com/RetellAI/retell-python-sdk/issues/113)) ([d0d0ef2](https://github.com/RetellAI/retell-python-sdk/commit/d0d0ef23ba863e18a6c92c3851a0e8ca2e4c4180))
* **api:** OpenAPI spec update via Stainless API ([#114](https://github.com/RetellAI/retell-python-sdk/issues/114)) ([f479ed8](https://github.com/RetellAI/retell-python-sdk/commit/f479ed89c8c8e98cbbf12dc8fced478b5f79adb2))
* **api:** OpenAPI spec update via Stainless API ([#115](https://github.com/RetellAI/retell-python-sdk/issues/115)) ([f382379](https://github.com/RetellAI/retell-python-sdk/commit/f3823799fd1ac35fb93d0fad5bbd25ac1ba93e43))
* **api:** OpenAPI spec update via Stainless API ([#116](https://github.com/RetellAI/retell-python-sdk/issues/116)) ([38aa122](https://github.com/RetellAI/retell-python-sdk/commit/38aa1222809618eed1c40a0dc1191792b83ddce1))

## 3.17.0 (2024-06-02)

Full Changelog: [v3.16.0...v3.17.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.16.0...v3.17.0)

### Features

* **api:** manual updates ([#106](https://github.com/RetellAI/retell-python-sdk/issues/106)) ([c15069e](https://github.com/RetellAI/retell-python-sdk/commit/c15069e5f73e06e268fb23edfb5d6b03d1766e9e))
* **api:** OpenAPI spec update via Stainless API ([#104](https://github.com/RetellAI/retell-python-sdk/issues/104)) ([49efca0](https://github.com/RetellAI/retell-python-sdk/commit/49efca0a34944ca93221e0ab8c31ef596df93601))

## 3.16.0 (2024-06-02)

Full Changelog: [v3.15.1...v3.16.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.15.1...v3.16.0)

### Features

* **api:** manual updates ([#102](https://github.com/RetellAI/retell-python-sdk/issues/102)) ([07c03db](https://github.com/RetellAI/retell-python-sdk/commit/07c03dbc7e1292750b0b84a2ada5d1528af922d0))
* **api:** manual updates ([#98](https://github.com/RetellAI/retell-python-sdk/issues/98)) ([34efb1a](https://github.com/RetellAI/retell-python-sdk/commit/34efb1a827e36fe1b560db13c47440f3456a66d4))
* **api:** OpenAPI spec update via Stainless API ([#100](https://github.com/RetellAI/retell-python-sdk/issues/100)) ([13e20f5](https://github.com/RetellAI/retell-python-sdk/commit/13e20f5aa61825e6e820be30ad68384d7107a8a8))
* **api:** OpenAPI spec update via Stainless API ([#101](https://github.com/RetellAI/retell-python-sdk/issues/101)) ([713b30a](https://github.com/RetellAI/retell-python-sdk/commit/713b30ade135ab46824101d4bf18a8592142065e))
* **api:** OpenAPI spec update via Stainless API ([#96](https://github.com/RetellAI/retell-python-sdk/issues/96)) ([1863aa2](https://github.com/RetellAI/retell-python-sdk/commit/1863aa236fa9511d0386293fe9aefd4e55624939))
* **api:** OpenAPI spec update via Stainless API ([#99](https://github.com/RetellAI/retell-python-sdk/issues/99)) ([d87ad31](https://github.com/RetellAI/retell-python-sdk/commit/d87ad3136d6c07ca3da7f7e763b288888b20276c))

## 3.15.1 (2024-05-20)

Full Changelog: [v3.15.0...v3.15.1](https://github.com/RetellAI/retell-python-sdk/compare/v3.15.0...v3.15.1)

### Bug Fixes

* **client:** correct formatting of array query params ([7d91e92](https://github.com/RetellAI/retell-python-sdk/commit/7d91e926042f2ecd5b2a9ece933cbc21eca68925))

## 3.15.0 (2024-05-20)

Full Changelog: [v3.14.0...v3.15.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.14.0...v3.15.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#87](https://github.com/RetellAI/retell-python-sdk/issues/87)) ([4869186](https://github.com/RetellAI/retell-python-sdk/commit/4869186ef68f3da1246dc6302ec959f065118a21))
* **api:** OpenAPI spec update via Stainless API ([#89](https://github.com/RetellAI/retell-python-sdk/issues/89)) ([49bd112](https://github.com/RetellAI/retell-python-sdk/commit/49bd1129cc05f6c6c113b933510d597038cc8ceb))


### Bug Fixes

* **client:** correct array format for query strings ([069cc04](https://github.com/RetellAI/retell-python-sdk/commit/069cc047958ba69cb5afac7a6dd197391b3801bd))

## 3.14.0 (2024-05-12)

Full Changelog: [v3.13.0...v3.14.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.13.0...v3.14.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#85](https://github.com/RetellAI/retell-python-sdk/issues/85)) ([28607e1](https://github.com/RetellAI/retell-python-sdk/commit/28607e18888f886c903deb369504def85d9e6926))

## 3.13.0 (2024-05-11)

Full Changelog: [v3.12.0...v3.13.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.12.0...v3.13.0)

### Features

* **api:** manual updates ([#83](https://github.com/RetellAI/retell-python-sdk/issues/83)) ([aafa41c](https://github.com/RetellAI/retell-python-sdk/commit/aafa41cdeabd0104945c64ff5026df2b1e7b86eb))
* **api:** manual updates ([#84](https://github.com/RetellAI/retell-python-sdk/issues/84)) ([e101c16](https://github.com/RetellAI/retell-python-sdk/commit/e101c169c7ff84e7dd1b650955854087c69763f8))
* **api:** OpenAPI spec update via Stainless API ([#79](https://github.com/RetellAI/retell-python-sdk/issues/79)) ([d5b8b30](https://github.com/RetellAI/retell-python-sdk/commit/d5b8b30f2eee346a9ce9c55af7498ca15f621add))
* **api:** OpenAPI spec update via Stainless API ([#81](https://github.com/RetellAI/retell-python-sdk/issues/81)) ([9d14e1d](https://github.com/RetellAI/retell-python-sdk/commit/9d14e1d127d649f010bcd14d9b6e49c70ae281a2))
* **api:** OpenAPI spec update via Stainless API ([#82](https://github.com/RetellAI/retell-python-sdk/issues/82)) ([6ec9a3e](https://github.com/RetellAI/retell-python-sdk/commit/6ec9a3e6d359497f7fd5094a7c3b41f4ca702ce2))

## 3.12.0 (2024-05-01)

Full Changelog: [v3.11.0...v3.12.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.11.0...v3.12.0)

### Features

* **api:** manual updates ([#78](https://github.com/RetellAI/retell-python-sdk/issues/78)) ([26071b4](https://github.com/RetellAI/retell-python-sdk/commit/26071b46c249b322659f1286f1fb1047b87cdda7))
* **api:** OpenAPI spec update via Stainless API ([#75](https://github.com/RetellAI/retell-python-sdk/issues/75)) ([379b4a5](https://github.com/RetellAI/retell-python-sdk/commit/379b4a515eba88e4ddaa6206fd99f0756b18998c))
* **api:** OpenAPI spec update via Stainless API ([#77](https://github.com/RetellAI/retell-python-sdk/issues/77)) ([c3be675](https://github.com/RetellAI/retell-python-sdk/commit/c3be675ec32b1d242928ad28ccef91e72a1e9cc2))

## 3.11.0 (2024-04-26)

Full Changelog: [v3.10.0...v3.11.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.10.0...v3.11.0)

### Features

* add package" ([45b5c3d](https://github.com/RetellAI/retell-python-sdk/commit/45b5c3d2d9ae9a78a5ae8b36b2d306551738176a))
* compile errors ([8a885a2](https://github.com/RetellAI/retell-python-sdk/commit/8a885a231b24cb01a170a9ed3f69ebbdde496459))
* webhook security ([b5fa4bd](https://github.com/RetellAI/retell-python-sdk/commit/b5fa4bdf9d9bc76b80394de405f1925ba1d8113d))

## 3.10.0 (2024-04-26)

Full Changelog: [v3.9.0...v3.10.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.9.0...v3.10.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#69](https://github.com/RetellAI/retell-python-sdk/issues/69)) ([5359b55](https://github.com/RetellAI/retell-python-sdk/commit/5359b55ec7daa7e2987b04358b70c0cb6e639868))
* **api:** OpenAPI spec update via Stainless API ([#71](https://github.com/RetellAI/retell-python-sdk/issues/71)) ([6dace9c](https://github.com/RetellAI/retell-python-sdk/commit/6dace9cc396322519f2e8dbc18fcb5704460c208))
* **api:** OpenAPI spec update via Stainless API ([#72](https://github.com/RetellAI/retell-python-sdk/issues/72)) ([f0828c0](https://github.com/RetellAI/retell-python-sdk/commit/f0828c044ba21f7cd9f7cb0922325cac5ceab33e))
* **api:** OpenAPI spec update via Stainless API ([#73](https://github.com/RetellAI/retell-python-sdk/issues/73)) ([9b4bd2a](https://github.com/RetellAI/retell-python-sdk/commit/9b4bd2a947e7860df7dc3b998436b2e5c750c715))

## 3.9.0 (2024-04-24)

Full Changelog: [v3.8.0...v3.9.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.8.0...v3.9.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#62](https://github.com/RetellAI/retell-python-sdk/issues/62)) ([395ddfc](https://github.com/RetellAI/retell-python-sdk/commit/395ddfc134e881821495bc653d7c23946f5f9f08))
* **api:** OpenAPI spec update via Stainless API ([#63](https://github.com/RetellAI/retell-python-sdk/issues/63)) ([64cdc71](https://github.com/RetellAI/retell-python-sdk/commit/64cdc71301bd82f3df157db82ac1ccb9b6420fd4))
* **api:** update via SDK Studio ([#59](https://github.com/RetellAI/retell-python-sdk/issues/59)) ([a78e8c2](https://github.com/RetellAI/retell-python-sdk/commit/a78e8c246d5a8a76689707a54677dd8052047083))
* **api:** update via SDK Studio ([#61](https://github.com/RetellAI/retell-python-sdk/issues/61)) ([8d97e8d](https://github.com/RetellAI/retell-python-sdk/commit/8d97e8def8c3efb45e308fe955214e19d9d07188))
* **api:** update via SDK Studio ([#64](https://github.com/RetellAI/retell-python-sdk/issues/64)) ([211e974](https://github.com/RetellAI/retell-python-sdk/commit/211e974a22b1d10adc7484e647381c13745765cb))
* **api:** update via SDK Studio ([#65](https://github.com/RetellAI/retell-python-sdk/issues/65)) ([46a5735](https://github.com/RetellAI/retell-python-sdk/commit/46a5735c31d825696efe1da944b7029e6a8fb67f))
* **api:** update via SDK Studio ([#66](https://github.com/RetellAI/retell-python-sdk/issues/66)) ([c9e8760](https://github.com/RetellAI/retell-python-sdk/commit/c9e876011d5a62ead8ea65e492cec457c05aec49))
* **api:** update via SDK Studio ([#67](https://github.com/RetellAI/retell-python-sdk/issues/67)) ([29a4cb1](https://github.com/RetellAI/retell-python-sdk/commit/29a4cb1ee2cea8ab4cc17b74558e3ffa5ae32db4))
* **api:** update via SDK Studio ([#68](https://github.com/RetellAI/retell-python-sdk/issues/68)) ([e66008d](https://github.com/RetellAI/retell-python-sdk/commit/e66008da5eb42308b8c0d97f8f35a41d3731c27d))

## 3.8.0 (2024-04-21)

Full Changelog: [v3.7.0...v3.8.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.7.0...v3.8.0)

### Features

* **api:** update via SDK Studio ([#57](https://github.com/RetellAI/retell-python-sdk/issues/57)) ([a964fb5](https://github.com/RetellAI/retell-python-sdk/commit/a964fb5861ba611c2790a1b38c9967640c6edcbf))

## 3.7.0 (2024-04-20)

Full Changelog: [v3.6.0...v3.7.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.6.0...v3.7.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#55](https://github.com/RetellAI/retell-python-sdk/issues/55)) ([8c034c2](https://github.com/RetellAI/retell-python-sdk/commit/8c034c2246df61369fa9383c04d63d3d7ad9ab8c))

## 3.6.0 (2024-04-16)

Full Changelog: [v3.5.0...v3.6.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.5.0...v3.6.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#51](https://github.com/RetellAI/retell-python-sdk/issues/51)) ([5207437](https://github.com/RetellAI/retell-python-sdk/commit/5207437ef2da2e59c3930526b6a576c5b17ab92b))
* **api:** OpenAPI spec update via Stainless API ([#53](https://github.com/RetellAI/retell-python-sdk/issues/53)) ([41deec0](https://github.com/RetellAI/retell-python-sdk/commit/41deec01753d2db6a4ee4cd93a91c66ef5de8b2f))
* **api:** OpenAPI spec update via Stainless API ([#54](https://github.com/RetellAI/retell-python-sdk/issues/54)) ([1a233db](https://github.com/RetellAI/retell-python-sdk/commit/1a233db002079497e5224db02a328a19f28735d0))

## 3.5.0 (2024-04-09)

Full Changelog: [v3.4.0...v3.5.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.4.0...v3.5.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#40](https://github.com/RetellAI/retell-python-sdk/issues/40)) ([a03bf90](https://github.com/RetellAI/retell-python-sdk/commit/a03bf90f56a00f6eab16cd00e2b4421baf0afcdf))
* **api:** OpenAPI spec update via Stainless API ([#41](https://github.com/RetellAI/retell-python-sdk/issues/41)) ([c2cf74c](https://github.com/RetellAI/retell-python-sdk/commit/c2cf74c755453d0261044ad53b6bbec56ad648f6))
* **api:** OpenAPI spec update via Stainless API ([#43](https://github.com/RetellAI/retell-python-sdk/issues/43)) ([15d48bc](https://github.com/RetellAI/retell-python-sdk/commit/15d48bc7f60f3cd19a260feac4653d00962c0dc3))
* **api:** OpenAPI spec update via Stainless API ([#45](https://github.com/RetellAI/retell-python-sdk/issues/45)) ([5b1dd2e](https://github.com/RetellAI/retell-python-sdk/commit/5b1dd2e5f84e4b9941f09f29e7290e79edc4bc94))
* **api:** OpenAPI spec update via Stainless API ([#47](https://github.com/RetellAI/retell-python-sdk/issues/47)) ([f9de6a2](https://github.com/RetellAI/retell-python-sdk/commit/f9de6a26081ead079bddb0e849ccbe1c3f79713b))
* **api:** OpenAPI spec update via Stainless API ([#48](https://github.com/RetellAI/retell-python-sdk/issues/48)) ([679b14d](https://github.com/RetellAI/retell-python-sdk/commit/679b14de819fdde12c87eac7325620a6de1add39))
* **api:** OpenAPI spec update via Stainless API ([#49](https://github.com/RetellAI/retell-python-sdk/issues/49)) ([f6946bb](https://github.com/RetellAI/retell-python-sdk/commit/f6946bb3ebea62631153e59e9657b26b3a912b35))
* **api:** OpenAPI spec update via Stainless API ([#50](https://github.com/RetellAI/retell-python-sdk/issues/50)) ([bb493f3](https://github.com/RetellAI/retell-python-sdk/commit/bb493f3584ffa972bf61e1bc68e5ba27123baf09))
* **api:** update via SDK Studio ([#38](https://github.com/RetellAI/retell-python-sdk/issues/38)) ([ae81995](https://github.com/RetellAI/retell-python-sdk/commit/ae81995d2e60df916798bb5912165b231206b03b))
* **api:** update via SDK Studio ([#42](https://github.com/RetellAI/retell-python-sdk/issues/42)) ([edbc78a](https://github.com/RetellAI/retell-python-sdk/commit/edbc78a33640b823010d5fd7e8e252d98207a00e))
* **api:** update via SDK Studio ([#44](https://github.com/RetellAI/retell-python-sdk/issues/44)) ([4ae3374](https://github.com/RetellAI/retell-python-sdk/commit/4ae337497e4c6fed1799aa69819d57a63d59e63a))
* **api:** update via SDK Studio ([#46](https://github.com/RetellAI/retell-python-sdk/issues/46)) ([7e9f13d](https://github.com/RetellAI/retell-python-sdk/commit/7e9f13d5e0b1e621fb809d5607450294951fdd39))

## 3.4.0 (2024-04-05)

Full Changelog: [v3.3.0...v3.4.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.3.0...v3.4.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#33](https://github.com/RetellAI/retell-python-sdk/issues/33)) ([e66b794](https://github.com/RetellAI/retell-python-sdk/commit/e66b79435d1375db65e1d5d5fe35d184b6bcb3b1))
* **api:** OpenAPI spec update via Stainless API ([#36](https://github.com/RetellAI/retell-python-sdk/issues/36)) ([6a640a4](https://github.com/RetellAI/retell-python-sdk/commit/6a640a4ced26ee672d5b4e649a500ea673efaa0b))
* **api:** OpenAPI spec update via Stainless API ([#37](https://github.com/RetellAI/retell-python-sdk/issues/37)) ([05fa284](https://github.com/RetellAI/retell-python-sdk/commit/05fa284ef46fc2d6c1970ace5e40a0e4079fc205))

## 3.3.0 (2024-03-29)

Full Changelog: [v3.2.0...v3.3.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.2.0...v3.3.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#31](https://github.com/RetellAI/retell-python-sdk/issues/31)) ([5b83e03](https://github.com/RetellAI/retell-python-sdk/commit/5b83e0331d1a75aa7bbcb92181c9012a9cb688af))

## 3.2.0 (2024-03-28)

Full Changelog: [v3.1.0...v3.2.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.1.0...v3.2.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#28](https://github.com/RetellAI/retell-python-sdk/issues/28)) ([7854389](https://github.com/RetellAI/retell-python-sdk/commit/7854389a3f89c8e25b6f4380b192f7a9d79b8e6d))
* **api:** OpenAPI spec update via Stainless API ([#30](https://github.com/RetellAI/retell-python-sdk/issues/30)) ([c35135a](https://github.com/RetellAI/retell-python-sdk/commit/c35135ac8a055afc5871567e0028bbdeefb55ad6))

## 3.1.0 (2024-03-27)

Full Changelog: [v3.0.0...v3.1.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.0.0...v3.1.0)

### Features

* **api:** update via SDK Studio ([#26](https://github.com/RetellAI/retell-python-sdk/issues/26)) ([0130013](https://github.com/RetellAI/retell-python-sdk/commit/0130013d9360370b2a83ffdbb142185e26944ddd))

## 3.0.0 (2024-03-26)

Full Changelog: [v0.1.0-alpha.5...v3.0.0](https://github.com/RetellAI/retell-python-sdk/compare/v0.1.0-alpha.5...v3.0.0)

### Features

* **api:** update via SDK Studio ([37356d8](https://github.com/RetellAI/retell-python-sdk/commit/37356d8b0e0ba809e6fc7128daaac517679fb16a))
* **api:** update via SDK Studio ([8f03138](https://github.com/RetellAI/retell-python-sdk/commit/8f031387fedc79545b80ef01c12a581a7efe8f14))
* **api:** update via SDK Studio ([3ef0339](https://github.com/RetellAI/retell-python-sdk/commit/3ef03393744c78be167a4b7f20ae718bfc57a7be))
* **api:** update via SDK Studio ([c9aac94](https://github.com/RetellAI/retell-python-sdk/commit/c9aac942c63a18f2fb59b90fba665e09a841e800))
* **api:** update via SDK Studio ([290cb85](https://github.com/RetellAI/retell-python-sdk/commit/290cb852ef13a5e7dd88ef5d239c94f73b098ffa))
* **api:** update via SDK Studio ([b8221ed](https://github.com/RetellAI/retell-python-sdk/commit/b8221ede7d97a11b731ab34632861547c2eba98c))
* **api:** update via SDK Studio ([054b303](https://github.com/RetellAI/retell-python-sdk/commit/054b3037a6e47a3eec992a59e21ddae14c38b8f2))
* **api:** update via SDK Studio ([7141964](https://github.com/RetellAI/retell-python-sdk/commit/7141964d7ca6562d49bd75432c3f1d62d2e22194))
* **api:** update via SDK Studio ([07021ed](https://github.com/RetellAI/retell-python-sdk/commit/07021ed4290343ccae0093caaaece849b9622f22))
* **api:** update via SDK Studio ([bc8943b](https://github.com/RetellAI/retell-python-sdk/commit/bc8943b8f376f7c1ad90b9c68cf3238734f65136))
* **api:** update via SDK Studio ([085a1c6](https://github.com/RetellAI/retell-python-sdk/commit/085a1c6b4566596f9db1acb95c8a84d0b942f5e2))
* **api:** update via SDK Studio ([0d714d7](https://github.com/RetellAI/retell-python-sdk/commit/0d714d7504df675161eded3c95d6c7189bbd3f61))
* **api:** update via SDK Studio ([047ff47](https://github.com/RetellAI/retell-python-sdk/commit/047ff47aeca6cc1cb43e999ad94b9946c8d35514))
* **api:** update via SDK Studio ([8a3c23e](https://github.com/RetellAI/retell-python-sdk/commit/8a3c23e49948709c2b405a25533e047d69adbd98))
* **api:** update via SDK Studio ([5b35eca](https://github.com/RetellAI/retell-python-sdk/commit/5b35eca9b34b41684ab8700c21c3a9c2ecc4b070))
* **api:** update via SDK Studio ([5505d55](https://github.com/RetellAI/retell-python-sdk/commit/5505d553fd7a2270cb0ef974d9eeec42af2328b0))
* **api:** update via SDK Studio ([d6440a0](https://github.com/RetellAI/retell-python-sdk/commit/d6440a06c853e65ca51e422320e9a952a21380ba))
* **api:** update via SDK Studio ([cae2bfd](https://github.com/RetellAI/retell-python-sdk/commit/cae2bfdec3298973d0430c03c93252f6b3acac90))
* **api:** update via SDK Studio ([bbb8b5b](https://github.com/RetellAI/retell-python-sdk/commit/bbb8b5bc4b6fd329a408c9a9550650946627abb2))
* **api:** update via SDK Studio ([5f99a59](https://github.com/RetellAI/retell-python-sdk/commit/5f99a59a97604b6c3f59e0032979efd206d402ce))
* **api:** update via SDK Studio ([e0b7fe3](https://github.com/RetellAI/retell-python-sdk/commit/e0b7fe38077c86e86766d219c2b12f036a3bff4d))
* **api:** update via SDK Studio ([#4](https://github.com/RetellAI/retell-python-sdk/issues/4)) ([470446d](https://github.com/RetellAI/retell-python-sdk/commit/470446dabd1e8a3f371d817debcce760c7566aca))
* **api:** update via SDK Studio ([#6](https://github.com/RetellAI/retell-python-sdk/issues/6)) ([d0018ba](https://github.com/RetellAI/retell-python-sdk/commit/d0018ba83f53b5f9ba729287eb1e7417705c94f9))
* **api:** update via SDK Studio ([#8](https://github.com/RetellAI/retell-python-sdk/issues/8)) ([073a0ff](https://github.com/RetellAI/retell-python-sdk/commit/073a0ff186f381023818aade9d2ec909a93d4137))
* **api:** update via SDK Studio ([#9](https://github.com/RetellAI/retell-python-sdk/issues/9)) ([ed6dfba](https://github.com/RetellAI/retell-python-sdk/commit/ed6dfbac3ddf20c1ee8a9ff78ab6e23df1be1a85))
* OpenAPI spec update ([6dbed1a](https://github.com/RetellAI/retell-python-sdk/commit/6dbed1a8a382913ed6d81ab52dbbec37019a4cde))


### Chores

* go live ([#2](https://github.com/RetellAI/retell-python-sdk/issues/2)) ([a7ea29d](https://github.com/RetellAI/retell-python-sdk/commit/a7ea29d9d2c2680bed319eed192094f22f1265ad))

## 0.1.0-alpha.5 (2024-03-26)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/RetellAI/retell-python-sdk/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** update via SDK Studio ([37356d8](https://github.com/RetellAI/retell-python-sdk/commit/37356d8b0e0ba809e6fc7128daaac517679fb16a))
* **api:** update via SDK Studio ([8f03138](https://github.com/RetellAI/retell-python-sdk/commit/8f031387fedc79545b80ef01c12a581a7efe8f14))
* **api:** update via SDK Studio ([3ef0339](https://github.com/RetellAI/retell-python-sdk/commit/3ef03393744c78be167a4b7f20ae718bfc57a7be))
* **api:** update via SDK Studio ([c9aac94](https://github.com/RetellAI/retell-python-sdk/commit/c9aac942c63a18f2fb59b90fba665e09a841e800))
* **api:** update via SDK Studio ([290cb85](https://github.com/RetellAI/retell-python-sdk/commit/290cb852ef13a5e7dd88ef5d239c94f73b098ffa))
* **api:** update via SDK Studio ([b8221ed](https://github.com/RetellAI/retell-python-sdk/commit/b8221ede7d97a11b731ab34632861547c2eba98c))
* **api:** update via SDK Studio ([054b303](https://github.com/RetellAI/retell-python-sdk/commit/054b3037a6e47a3eec992a59e21ddae14c38b8f2))
* **api:** update via SDK Studio ([7141964](https://github.com/RetellAI/retell-python-sdk/commit/7141964d7ca6562d49bd75432c3f1d62d2e22194))
* **api:** update via SDK Studio ([07021ed](https://github.com/RetellAI/retell-python-sdk/commit/07021ed4290343ccae0093caaaece849b9622f22))
* **api:** update via SDK Studio ([bc8943b](https://github.com/RetellAI/retell-python-sdk/commit/bc8943b8f376f7c1ad90b9c68cf3238734f65136))
* **api:** update via SDK Studio ([085a1c6](https://github.com/RetellAI/retell-python-sdk/commit/085a1c6b4566596f9db1acb95c8a84d0b942f5e2))
* **api:** update via SDK Studio ([0d714d7](https://github.com/RetellAI/retell-python-sdk/commit/0d714d7504df675161eded3c95d6c7189bbd3f61))
* **api:** update via SDK Studio ([047ff47](https://github.com/RetellAI/retell-python-sdk/commit/047ff47aeca6cc1cb43e999ad94b9946c8d35514))
* **api:** update via SDK Studio ([8a3c23e](https://github.com/RetellAI/retell-python-sdk/commit/8a3c23e49948709c2b405a25533e047d69adbd98))
* **api:** update via SDK Studio ([5b35eca](https://github.com/RetellAI/retell-python-sdk/commit/5b35eca9b34b41684ab8700c21c3a9c2ecc4b070))
* **api:** update via SDK Studio ([5505d55](https://github.com/RetellAI/retell-python-sdk/commit/5505d553fd7a2270cb0ef974d9eeec42af2328b0))
* **api:** update via SDK Studio ([d6440a0](https://github.com/RetellAI/retell-python-sdk/commit/d6440a06c853e65ca51e422320e9a952a21380ba))
* **api:** update via SDK Studio ([cae2bfd](https://github.com/RetellAI/retell-python-sdk/commit/cae2bfdec3298973d0430c03c93252f6b3acac90))
* **api:** update via SDK Studio ([bbb8b5b](https://github.com/RetellAI/retell-python-sdk/commit/bbb8b5bc4b6fd329a408c9a9550650946627abb2))
* **api:** update via SDK Studio ([5f99a59](https://github.com/RetellAI/retell-python-sdk/commit/5f99a59a97604b6c3f59e0032979efd206d402ce))
* **api:** update via SDK Studio ([e0b7fe3](https://github.com/RetellAI/retell-python-sdk/commit/e0b7fe38077c86e86766d219c2b12f036a3bff4d))
* **api:** update via SDK Studio ([#4](https://github.com/RetellAI/retell-python-sdk/issues/4)) ([470446d](https://github.com/RetellAI/retell-python-sdk/commit/470446dabd1e8a3f371d817debcce760c7566aca))
* **api:** update via SDK Studio ([#6](https://github.com/RetellAI/retell-python-sdk/issues/6)) ([d0018ba](https://github.com/RetellAI/retell-python-sdk/commit/d0018ba83f53b5f9ba729287eb1e7417705c94f9))
* **api:** update via SDK Studio ([#8](https://github.com/RetellAI/retell-python-sdk/issues/8)) ([073a0ff](https://github.com/RetellAI/retell-python-sdk/commit/073a0ff186f381023818aade9d2ec909a93d4137))
* **api:** update via SDK Studio ([#9](https://github.com/RetellAI/retell-python-sdk/issues/9)) ([ed6dfba](https://github.com/RetellAI/retell-python-sdk/commit/ed6dfbac3ddf20c1ee8a9ff78ab6e23df1be1a85))
* OpenAPI spec update ([6dbed1a](https://github.com/RetellAI/retell-python-sdk/commit/6dbed1a8a382913ed6d81ab52dbbec37019a4cde))


### Chores

* go live ([#2](https://github.com/RetellAI/retell-python-sdk/issues/2)) ([a7ea29d](https://github.com/RetellAI/retell-python-sdk/commit/a7ea29d9d2c2680bed319eed192094f22f1265ad))

## 0.1.0-alpha.4 (2024-03-26)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/RetellAI/retell-python-sdk/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** update via SDK Studio ([#9](https://github.com/RetellAI/retell-python-sdk/issues/9)) ([ed6dfba](https://github.com/RetellAI/retell-python-sdk/commit/ed6dfbac3ddf20c1ee8a9ff78ab6e23df1be1a85))

## 0.1.0-alpha.3 (2024-03-26)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/RetellAI/retell-python-sdk/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** update via SDK Studio ([#6](https://github.com/RetellAI/retell-python-sdk/issues/6)) ([d0018ba](https://github.com/RetellAI/retell-python-sdk/commit/d0018ba83f53b5f9ba729287eb1e7417705c94f9))
* **api:** update via SDK Studio ([#8](https://github.com/RetellAI/retell-python-sdk/issues/8)) ([073a0ff](https://github.com/RetellAI/retell-python-sdk/commit/073a0ff186f381023818aade9d2ec909a93d4137))

## 0.1.0-alpha.2 (2024-03-26)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/RetellAI/retell-python-sdk/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([#4](https://github.com/RetellAI/retell-python-sdk/issues/4)) ([470446d](https://github.com/RetellAI/retell-python-sdk/commit/470446dabd1e8a3f371d817debcce760c7566aca))

## 0.1.0-alpha.1 (2024-03-26)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/RetellAI/retell-python-sdk/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([37356d8](https://github.com/RetellAI/retell-python-sdk/commit/37356d8b0e0ba809e6fc7128daaac517679fb16a))
* **api:** update via SDK Studio ([8f03138](https://github.com/RetellAI/retell-python-sdk/commit/8f031387fedc79545b80ef01c12a581a7efe8f14))
* **api:** update via SDK Studio ([3ef0339](https://github.com/RetellAI/retell-python-sdk/commit/3ef03393744c78be167a4b7f20ae718bfc57a7be))
* **api:** update via SDK Studio ([c9aac94](https://github.com/RetellAI/retell-python-sdk/commit/c9aac942c63a18f2fb59b90fba665e09a841e800))
* **api:** update via SDK Studio ([290cb85](https://github.com/RetellAI/retell-python-sdk/commit/290cb852ef13a5e7dd88ef5d239c94f73b098ffa))
* **api:** update via SDK Studio ([b8221ed](https://github.com/RetellAI/retell-python-sdk/commit/b8221ede7d97a11b731ab34632861547c2eba98c))
* **api:** update via SDK Studio ([054b303](https://github.com/RetellAI/retell-python-sdk/commit/054b3037a6e47a3eec992a59e21ddae14c38b8f2))
* **api:** update via SDK Studio ([7141964](https://github.com/RetellAI/retell-python-sdk/commit/7141964d7ca6562d49bd75432c3f1d62d2e22194))
* **api:** update via SDK Studio ([07021ed](https://github.com/RetellAI/retell-python-sdk/commit/07021ed4290343ccae0093caaaece849b9622f22))
* **api:** update via SDK Studio ([bc8943b](https://github.com/RetellAI/retell-python-sdk/commit/bc8943b8f376f7c1ad90b9c68cf3238734f65136))
* **api:** update via SDK Studio ([085a1c6](https://github.com/RetellAI/retell-python-sdk/commit/085a1c6b4566596f9db1acb95c8a84d0b942f5e2))
* **api:** update via SDK Studio ([0d714d7](https://github.com/RetellAI/retell-python-sdk/commit/0d714d7504df675161eded3c95d6c7189bbd3f61))
* **api:** update via SDK Studio ([047ff47](https://github.com/RetellAI/retell-python-sdk/commit/047ff47aeca6cc1cb43e999ad94b9946c8d35514))
* **api:** update via SDK Studio ([8a3c23e](https://github.com/RetellAI/retell-python-sdk/commit/8a3c23e49948709c2b405a25533e047d69adbd98))
* **api:** update via SDK Studio ([5b35eca](https://github.com/RetellAI/retell-python-sdk/commit/5b35eca9b34b41684ab8700c21c3a9c2ecc4b070))
* **api:** update via SDK Studio ([5505d55](https://github.com/RetellAI/retell-python-sdk/commit/5505d553fd7a2270cb0ef974d9eeec42af2328b0))
* **api:** update via SDK Studio ([d6440a0](https://github.com/RetellAI/retell-python-sdk/commit/d6440a06c853e65ca51e422320e9a952a21380ba))
* **api:** update via SDK Studio ([cae2bfd](https://github.com/RetellAI/retell-python-sdk/commit/cae2bfdec3298973d0430c03c93252f6b3acac90))
* **api:** update via SDK Studio ([bbb8b5b](https://github.com/RetellAI/retell-python-sdk/commit/bbb8b5bc4b6fd329a408c9a9550650946627abb2))
* **api:** update via SDK Studio ([5f99a59](https://github.com/RetellAI/retell-python-sdk/commit/5f99a59a97604b6c3f59e0032979efd206d402ce))
* **api:** update via SDK Studio ([e0b7fe3](https://github.com/RetellAI/retell-python-sdk/commit/e0b7fe38077c86e86766d219c2b12f036a3bff4d))
* OpenAPI spec update ([6dbed1a](https://github.com/RetellAI/retell-python-sdk/commit/6dbed1a8a382913ed6d81ab52dbbec37019a4cde))


### Chores

* go live ([#2](https://github.com/RetellAI/retell-python-sdk/issues/2)) ([a7ea29d](https://github.com/RetellAI/retell-python-sdk/commit/a7ea29d9d2c2680bed319eed192094f22f1265ad))
